<?php
/*
Plugin Name: Amazon Niche Store
Plugin URI: http://geeklad.com/build-your-own-amazon-niche-store
Description: Display your own Amazon store on your blog.  Click <a href="tools.php?page=amazon_niche_store">here</a> to quickly add multiple new store pages.  To display a store in a page or post:  <code>[amazon trackingid="YOUR-CAMPAIGN-ID" keywords="YOUR-STORE-KEYWORDS" rows="NUMBER-OF-ROWS-YOU-WANT-TO-DISPLAY" columns="NUMBER-OF-COLUMNS-YOU-WANT-TO-DISPLAY" pagination="yes" vertical="yes"]</code>  Use spaces between the keywords.  You can also <a href="widgets.php">display the store as a widget</a>.
Author: GeekLad
Version: 1.1
Author URI: http://geeklad.com/
License: GPL
*/

/*  Copyright 2009 GeekLad (email : geeklad@geeklad.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/


add_shortcode('amazon', 'amazon_store_display');
function amazon_store_display($atts) {
	extract(shortcode_atts(array(
			'trackingid' => false,
			'keywords' => false,
			'rows' => '5',
			'columns' => '2',
			'pagination' => false,
			'customcss' => false,
			'logo' => 'white',
		), $atts));
		
		if (!$keywords || !$trackingid)
			return "";
		
		if ($pagination && $pagination != "none") {
			$pagination = "&pagination=yes";
			if ($_GET['pagenumber'])
				$pagination .= "&pagenumber=" . $_GET['pagenumber'];
			else
				$pagination .= "&pagenumber=1";
		}
		
		
		if ($customcss && $customcss != "none")
			$customcss = "&customcss=sidebar";			
		$logo = "&logo=" . $logo;

		$keywords = urlencode($keywords);
		$storeurl = "http://geeklad.com/tools/amazon/amazon.php?trackingid=$trackingid&rows=$rows&columns=$columns$pagination$customcss$logo&keyword=$keywords";
		return file_get_contents($storeurl);
}

add_action("plugins_loaded", "amazon_store_widget_init");
function amazon_store_widget_init() {
	wp_register_widget_control("free_amazon_store_widget", __('Amazon Niche Store'), 'amazon_store_widget_control');
	wp_register_sidebar_widget("free_amazon_store_widget", __('Amazon Niche Store'), 'amazon_store_widget', array('description' => __('Display an Amazon niche store as a widget.')));
}

function amazon_store_widget_control() {
	$options = $newoptions = get_option('amazon_store_widget');
	if ( $_POST["amazon_store_widget_submit"] ) {
		$newoptions['title'] = $_POST["amazon_store_widget_title"];
		$newoptions['trackingid'] = $_POST["amazon_store_widget_trackingid"];
		$newoptions['keywords'] = $_POST["amazon_store_widget_keywords"];
		$newoptions['itemcount'] = $_POST["amazon_store_widget_itemcount"];
		$newoptions['css'] = str_replace("\"", "'", str_replace("\\", "", $_POST["amazon_store_widget_css"]));
	}
	
	if ( empty($options['keywords']) && empty($options['trackingid']) ) {
		$title = "Buy on Amazon";
		$keywords = "";
		$itemcount = 3;
		$css = ".amazon-store-sidebar, .amazon-store-sidebar table {
 font-size: small;
 font-family: verdana,arial,helvetica,sans-serif;
 width: 100%;
 min-width: 100%;
}
.amazon-store-sidebar a {
 text-decoration: none;
}
.amazon-store-sidebar td {
 vertical-align: top;
 font-size: small;
}
.amazon-store-sidebar-title {
 text-decoration: underline;
 font-weight: bold;
 font-size: 110%;
}
.amazon-store-sidebar-manufacturer {
 color: #000000;
}	
.amazon-store-sidebar-price {
 color: #990000;
 font-weight: bold;
}
.amazon-store-sidebar-price strike {
 color: #000000;
 font-weight: normal;
}
.amazon-store-details-arrow {
 color: #E47911;
 font-size: 120%;
 font-weight: bold;
 font-family: verdana,arial,helvetica,sans-serif;
}
.amazon-store-sidebar-view-details {
 text-decoration: underline;
 color: #004B91;
 font-family: verdana,arial,helvetica,sans-serif;
}
.amazon-store-sidebar-footer {
 line-height: 14px;
 font-size: 10px;
 font-style: italic;
 margin-top: -10px;
 font-family:  verdana,arial,helvetica,sans-serif;
}
";
	}
	else {
		$title = $newoptions['title'];
		$trackingid = $newoptions['trackingid'];
		$keywords = $newoptions['keywords'];
		$itemcount = $newoptions['itemcount'];
		$css = $newoptions['css'];
	}
	
	if ( $options != $newoptions ) {
		$options = $newoptions;
		update_option('amazon_store_widget', $options);
	}
?>
			<p><label for="amazon-store-widget-title"><?php _e('Title:'); ?> <input class="widefat" name="amazon_store_widget_title" type="text" value="<?php echo $title; ?>" title="This will be the title of the widget on your webpage."/></label></p>
			<p>
				<label for="amazon-store-widget-trackingid"><?php _e('Tracking ID<br>'); ?><input type="text" name="amazon_store_widget_trackingid" value="<?php echo $trackingid; ?>" title="Don't forget your Amazon Tracking ID!" />
				<br />
			</p>
			<p>
				<label for="amazon-store-widget-keywords"><?php _e('Keywords<br>'); ?><input type="text" name="amazon_store_widget_keywords" value="<?php echo $keywords; ?>" title="You can specify multiple sets of keywords by separating them with a pipe character (|).  For example, to display teddy bears or inflatable pools at random, you would enter they keywords as: teddy bear|inflatable pool"/>
				<br />
			</p>
			<p>
				<label for="amazon-store-widget-itemcount"><?php _e('# Items to Display<br>'); ?><input type="text" name="amazon_store_widget_itemcount" value="<?php echo $itemcount; ?>" title="The number of items to display in the widget."/>
				<br />
			</p>
			<p>
				<label for="amazon-store-widget-custom-css"><?php _e('Custom CSS<br>'); ?><textarea rows="20" columns="50" name="amazon_store_widget_css" title="Customize the look and feel of your widget.  Valid CSS code must be used."><?php echo $css; ?></textarea>
				<br />
			</p>
			<input type="hidden" id="amazon_store_widget_submit" name="amazon_store_widget_submit" value="1" />
<?php
}

function amazon_store_widget($args) {
	$options = get_option('amazon_store_widget');
	if ($options['keywords'] && $options['trackingid']) {
		if ( '%BEG_OF_TITLE%' != $args['before_title'] ) {
			if ( $output = wp_cache_get('amazon_store_widget', 'widget') )
				return print($output);
			ob_start();
		}

		extract($args);
		$keywords = @preg_split("/\|/", $options['keywords']);
		if (!$keywords)
			$keywords = $options['keywords'];
		else
			$keywords = $keywords[rand(0, count($keywords)-1)];
		$options['keywords'] = $keywords;
		$options['logo'] = "none";
		$options['customcss'] = "yes";
		$options['columns'] = 1;
		$options['rows'] = $options['itemcount'];

		echo "<style type=\"text/css\">" . $options['css'] . "</style>";
		echo $before_title . $title . $after_title;
		echo str_replace("\\", "", $before);
		echo amazon_store_display($options);
		
		if ( '%BEG_OF_TITLE%' != $args['before_title'] )
			wp_cache_add('amazon_store_widget', ob_get_flush(), 'widget');
	}
}

add_action('admin_menu', 'amazon_store_add_admin');
function amazon_store_add_admin() {
	add_submenu_page('tools.php', 'Add Amazon Niche Store Pages', 'Amazon Store', 8, 'amazon_niche_store', 'amazon_store_add_pages');
}
function amazon_store_add_pages() {
	if ($_POST['action']) {
		if ($_POST['tracking_id']) {
			update_option('amazon_store_options', array(
				"tracking_id" => $_POST['tracking_id'],
				"customcss" => $_POST['customcss'],
				"post_status" => $_POST['post_status'],
				"rows" => $_POST['rows'],
				"columns" => $_POST['columns'],
				"pagination" => $_POST['pagination'],
				"logo" => $_POST['logo']				
			));

			$post = 0;
			$addcount = 0;
			$options = get_option('amazon_store_options');
			$tracking_id = $options['tracking_id'];
			$rows = $options['rows'];
			$columns = $options['columns'];
			if ($options['pagination'] == "yes")
				$pagination = " pagination=\"yes\"";
			else
				$pagination = "";
			if ($options['customcss'] != "")
				$customcss = " customcss=\"" . $options['customcss'] . "\"";
			else
				$customcss = "";
			$logo = $options['logo'];
			while ($_POST['title_' . $post]) {
				if ($_POST['title_' . $post] && $_POST['keywords_' . $post]) {
					$keywords = $_POST['keywords_' . $post];
					$shortcode = str_replace("  ", " ", trim("[amazon trackingid=\"$tracking_id\" keywords=\"$keywords\" rows=\"$rows\" columns=\"$columns\" logo=\"$logo\" $pagination $customcss")) . "]";
					$new_post = array();
					$new_post['post_title'] = $_POST['title_' . $post];
					$new_post['post_content'] = $shortcode;
					$new_post['post_status'] = $options['post_status'];
					$new_post['post_author'] = 1;
					$new_post['post_type'] = 'page';
					$new_post['post_parent'] = $_POST['post_parent_' . $post];
					$post_id = wp_insert_post($new_post);
					$addcount++;
				}
				$post++;
			}
			if ($addcount > 0) {
				echo "<div class=\"updated\"><p>Added $addcount page";
				if ($addcount > 1)
					echo "s";
				echo "</p></div>";
			}
			else {
				echo "<div class=\"updated\"><p>Updated your store page preferences. Note: <strong style=\"color: #FF0000\">This will not change existing store pages</strong>. You will have to edit existing pages manually.</p></div>";
			}
		}
	}
	$options = get_option('amazon_store_options');
	if (!$options['post_status']) {
		$options['post_status'] = "draft";
		$options['rows'] = "2";
		$options['columns'] = "5";
		$options['pagination'] = "yes";
		$options['logo'] = "white";
		update_option('amazon_store_options', $options);
	}
?>
	<div class="wrap">
		<h2>Add Amazon Niche Store Pages</h2>
		<div class="metabox-holder">
			<div class="inner-sidebar">
			</div>
			<div class="has-sidebar sm-padded">
				<div class="meta-box-sortabless">
					<div class="postbox">
						<h3 class="hndle"><span>Add Amazon Niche Store Pages</span></h3> 
						<div class="inside">
							<ul>
								<li>
									<form method="post" action="<?php echo str_replace( '%7E', '~', $_SERVER['REQUEST_URI']); ?>">
										<?php wp_nonce_field('update-options'); ?>
										<br>Your Amazon Tracking ID: <input type="text" name="tracking_id" size="25" value="<?php echo $options['tracking_id']; ?>"/><br>
										Custom CSS (leave blank to use default): <input type="text" name="customcss" value="<?php echo $options['customcss']; ?>"><br>
										Post Status: <select name="post_status">
											<option value="draft"<?php if($options['post_status'] == "draft") echo " selected";?>>Draft</option>
											<option value="publish"<?php if($options['post_status'] == "publish") echo " selected";?>>Publish</option>
										</select><br>
										Rows: <select name="rows">
											<option value="1"<?php if($options['rows'] == "1") echo " selected";?>>1</option>
											<option value="2"<?php if($options['rows'] == "2") echo " selected";?>>2</option>
											<option value="3"<?php if($options['rows'] == "3") echo " selected";?>>3</option>
											<option value="4"<?php if($options['rows'] == "4") echo " selected";?>>4</option>
											<option value="5"<?php if($options['rows'] == "5") echo " selected";?>>5</option>
											<option value="6"<?php if($options['rows'] == "6") echo " selected";?>>6</option>
											<option value="7"<?php if($options['rows'] == "7") echo " selected";?>>7</option>
											<option value="8"<?php if($options['rows'] == "8") echo " selected";?>>8</option>
											<option value="9"<?php if($options['rows'] == "9") echo " selected";?>>9</option>
											<option value="10"<?php if($options['rows'] == "10") echo " selected";?>>10</option>
										</select><br>
										Columns: <select name="columns">
											<option value="1"<?php if($options['columns'] == "1") echo " selected";?>>1</option>
											<option value="2"<?php if($options['columns'] == "2") echo " selected";?>>2</option>
											<option value="3"<?php if($options['columns'] == "3") echo " selected";?>>3</option>
											<option value="4"<?php if($options['columns'] == "4") echo " selected";?>>4</option>
											<option value="5"<?php if($options['columns'] == "5") echo " selected";?>>5</option>
											<option value="6"<?php if($options['columns'] == "6") echo " selected";?>>6</option>
											<option value="7"<?php if($options['columns'] == "7") echo " selected";?>>7</option>
											<option value="8"<?php if($options['columns'] == "8") echo " selected";?>>8</option>
											<option value="9"<?php if($options['columns'] == "9") echo " selected";?>>9</option>
											<option value="10"<?php if($options['columns'] == "10") echo " selected";?>>10</option>
										</select><br>
										Pagination: <select name="pagination">
											<option value="yes"<?php if($options['pagination'] == "yes") echo " selected";?>>Yes</option>
											<option value="no"<?php if($options['pagination'] == "no") echo " selected";?>>No</option>
										</select><br>
										Logo Option: <select name="logo">
											<option value="white"<?php if($options['logo'] == "white") echo " selected";?>>White</option>
											<option value="black"<?php if($options['logo'] == "black") echo " selected";?>>Black</option>
											<option value="none"<?php if($options['logo'] == "none") echo " selected";?>>None</option>
										</select><br><br>
										<table>
											<tr>
												<th>Page Title</td>
												<th>Product Keywords</th>
												<th>Page Parent</th>
											</tr>
											<?php for ($loop=0; $loop<=10; $loop++) { ?>
											<tr>
												<td>
													<input type="text" name="title_<?php echo $loop; ?>">
												</td>
												<td>
													<input type="text" name="keywords_<?php echo $loop; ?>">
												</td>
												<td>
													<?php amazon_store_display_pages($loop); ?>
												</td>
											</tr>
											<?php } ?>
										</table>
										<input type="hidden" name="action" value="stores-added" />
										<input type="submit" class="button-primary" value="<?php _e('Add Pages') ?>" />
									</form>
								</li>
							</ul>
						</div>
					</div>
				</div>
			</div>
		</div>
	</div>
<?php
}

function amazon_store_display_pages($row) {
	$pages = get_pages();
?>
													<select name="post_parent_<?php echo $row; ?>">
														<option value="0" selected>None</option>
<?php
	foreach ($pages as $page) {
		if ($page->post_status == "publish") {
?>
														<option value="<?php echo $page->ID; ?>"><?php echo $page->post_title; ?></option>
<?php
		}
	}
?>
													</select>
<?php
}
?>
